import tkinter as tk
from tkinter import filedialog


def dialog(file_dict):
    root = tk.Tk()
    root.withdraw()
    root.deiconify()

    file_path = filedialog.askopenfilename(filetypes=[(file_dict[0], file_dict[1])])

    root.quit()
    root.destroy()
    return file_path if file_path else None




import eel
import subprocess
import os
from Build_Python_To_exe_for_Clung.python_files.file_dialog import dialog as fd

@eel.expose
def open_file_dialog():
    file_type = ("Python Files", "*.py")
    file_path = fd(file_type)
    return file_path


@eel.expose
def open_ico_file_dialog():
    file_type = ("Icon Files", "*.ico")
    file_path = fd(file_type)
    return file_path

@eel.expose
def receive_data_from_js(content):
    try:
        process = subprocess.Popen(
            content,
            shell=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True,
        )

        for line in process.stdout:
            eel.update_text_area(line.strip())
        for line in process.stderr:
            eel.update_text_area(f"ERROR: {line.strip()}")

        process.wait()
        eel.update_text_area("Command execution completed.")
    except Exception as e:
        eel.update_text_area(f"Command execution failed: {str(e)}")


def main():
    eel.init(os.path.join(os.path.dirname(__file__), "web"))
    eel.start("main.html", size=(1024, 768))

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    name="py_nui_exe",  # パッケージ名
    version="0.1.0",
    author="CKM",
    description="python→exe setup build support tool",
    long_description=open("README.md",encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/KMASTERgit/py_nui_exe",
    packages=[
        "Build_Python_To_exe_for_Clung",
        "Build_Python_To_exe_for_Clung.python_files"
    ],  # サブパッケージを含める
    include_package_data=True,
    install_requires=[
        "eel>=0.18.1",
        "nuitka>=2.5.7",
    ],
    entry_points={
        "console_scripts": [
            "py-nui-exe=Build_Python_To_exe_for_Clung.app:main",  # コマンド設定
        ],
    },
    package_data={
        "Build_Python_To_exe_for_Clung": [
            "Web/**/*",  # Web配下の静的ファイル
            "python_files/*.py",  # python_files配下のPythonファイル
        ],
    },
)
